@@ -27,8 +27,6 @@
 #define BABL_LIST_SEPERATOR ':'
 #endif
 
-
-
 #define BABL_INIT_HOOK     init_hook();
 #define BABL_DESTROY_HOOK  destroy_hook();
 
@@ -140,12 +138,24 @@ destroy_hook (void)
 
 #ifdef HAVE_DLFCN_H
 #include <dlfcn.h>
+#define HLIB void *
 #endif
 
 #ifndef RTLD_NOW
 #define RTLD_NOW 0
 #endif
 
+#ifdef WIN32 
+#define WIN32_LEAN_AND_MEAN 
+#include <windows.h>
+#define HLIB   HINSTANCE
+
+#define dlopen(a, b) LoadLibrary(a) 
+#define dlsym(l, s)  GetProcAddress(l, s) 
+#define dlclose(l)   FreeLibrary(l) 
+#define dlerror()    GetLastError()
+#endif 
+
 static Babl *
 load_failed (Babl *babl)
 {
@@ -161,10 +171,8 @@ static Babl *
 babl_extension_load (const char *path)
 {
   Babl *babl             = NULL;
-
-#ifdef HAVE_DLOPEN
   /* do the actual loading thing */
-  void *dl_handle        = NULL;
+  HLIB dl_handle         = NULL;
   int  (*init)    (void) = NULL;
   void (*destroy) (void) = NULL;
  
@@ -192,7 +200,6 @@ babl_extension_load (const char *path)
       babl_log ("babl_extension_init() in extension '%s' failed (return!=0)", path);
       return load_failed (babl);
     }
-#endif
 
   if (babl_db_insert (db, babl) == babl)
     {
@@ -337,10 +344,8 @@ each_babl_extension_destroy (Babl *babl,
 {
   if (babl->extension.destroy)
     babl->extension.destroy();
-#ifdef HAVE_DLOPEN
   if (babl->extension.dl_handle)
     dlclose (babl->extension.dl_handle);
-#endif
 
   babl_free (babl);
   return 0;  /* continue iterating */
